"use strict";

module.exports = function (_ref) {
  var t = _ref.types;
  var childVisitor = {
    JSXOpeningElement: function JSXOpeningElement(path, state) {
      var parentComponentStack = state.parentComponentStack,
        config = state.config,
        isRootComponent = state.isRootComponent;
      var parentComponentName = parentComponentStack[parentComponentStack.length - 1];
      var componentName = path.node.name.name;
      if (isRootComponent && parentComponentName) {
        console.log(componentName, parentComponentName);
        // Check if it matches config
        var matched = (Array.isArray(config.components) ? config.components.includes(componentName) : config.components === componentName) && (Array.isArray(config.parentsToExclude) ? !config.parentsToExclude.includes(parentComponentName) : config.parentsToExclude !== parentComponentName);
        var classNameToAdd = parentComponentName;
        if (matched) {
          // Apply the matched rule to add className attribute

          // Check if className attribute already exists
          var classNameAttribute = path.node.attributes.find(function (attr) {
            return attr.name && attr.name.name === 'className';
          });
          if (!classNameAttribute) {
            // Create a new className attribute with the specified classNameToAdd
            var newClassNameAttribute = t.jsxAttribute(t.jsxIdentifier('className'), t.stringLiteral(classNameToAdd));

            // Append the new className attribute to the JSX element
            path.node.attributes.push(newClassNameAttribute);
          } else {
            // Append classNameToAdd to the existing className, if not already included
            var currentClassName = classNameAttribute.value.value;
            if (!currentClassName.includes(classNameToAdd)) {
              classNameAttribute.value = t.stringLiteral(currentClassName + " " + classNameToAdd);
            }
          }
        }
        state.isRootComponent = false;
      }
    }
  };
  return {
    visitor: {
      Program: function Program(path, state) {
        // Read config from Babel configuration
        var _state$opts = state.opts,
          components = _state$opts.components,
          parentsToExclude = _state$opts.parentsToExclude; // Initialize parent component name stack
        state.parentComponentStack = [];
        state.isRootComponent = true;

        // Store config in plugin state
        state.config = {
          components: components,
          parentsToExclude: parentsToExclude
        };

        // Traverse the program with the childVisitor
        path.traverse(childVisitor, state);
      },
      FunctionDeclaration: function FunctionDeclaration(path, state) {
        // Track parent component name for function components
        var parentComponentStack = state.parentComponentStack;
        var componentName = path.node.id.name;
        parentComponentStack.push(componentName);

        // Continue traversal
        path.traverse(childVisitor, state);

        // Pop the component name when exiting
        parentComponentStack.pop();
      },
      VariableDeclarator: function VariableDeclarator(path, state) {
        // Track parent component name for variable-declared components
        var parentComponentStack = state.parentComponentStack;
        var componentName = path.node.id.name;
        parentComponentStack.push(componentName);

        // Continue traversal
        path.traverse(childVisitor, state);

        // Pop the component name when exiting
        parentComponentStack.pop();
      }
    }
  };
};